==> bplan-base-globals-1.0.0-9a5454.zip: lang/de/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'de',
    'language' => 'Deutsch',
    'locale' => 'de_DE',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value €',
    'currency.format.negative' => '-:value €',
    'currency.iso4217.alpha'   => 'EUR',
    'currency.iso4217.numeric' => 978,
    'currency.name'            => 'Euro',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Eurocent',
    'currency.subunit.symbol'  => 'ct',
    'currency.symbol'          => '€',

    'date.format'       => 'd.m.Y',
    'datetime.format'   => 'd.m.Y, H:i',
    'datetime.format+'  => 'd.m.Y, H:i:s',
    'datetime.format-+' => 'd.m.Y, H:i \U\h\r',
    'datetime.format++' => 'd.m.Y, H:i:s \U\h\r',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i \U\h\r',
    'time.format++'     => 'H:i:s \U\h\r',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => '.',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------


    'action.add'           => 'Hinzufügen',
    'action.cancel'        => 'Abbrechen',
    'action.cancel-upload' => 'Hochladen abbrechen',
    'action.change'        => 'Ändern',
    'action.close'         => 'Schließen',
    'action.delete'        => 'Löschen',
    'action.confirm'       => 'Bestätigen',
    'action.edit'          => 'Bearbeiten',
    'action.save'          => 'Speichern',
    'action.search'        => 'Suchen',
    'action.upload'        => 'Datei hochladen',
    'action.verify'        => 'Verifizieren',
    'action.view'          => 'View',

    'languages' => [
        'bg' => 'Bulgarisch',
        'de' => 'Deutsch',
        'en' => 'Englisch',
        'es' => 'Spanisch',
        'fr' => 'Französisch',
        'hu' => 'Ungarisch',
        'it' => 'Italienisch',
        'lt' => 'Litauisch',
        'pl' => 'Polnisch',
        'ro' => 'Rumänisch',
        'ru' => 'Russisch',
        'tr' => 'Türkisch',
        'uk' => 'Ukrainisch',
    ],

    'option.yes' => 'Ja',
    'option.no'  => 'Nein',

    'required-hint'   => 'Markierte Felder (<span class="required-marker">:marker</span>) sind Pflichtfelder',
    'required-marker' => '*',

    'select-option.please-select' => ' -- Bitte wählen -- ',

    'status.active'   => 'Aktiv',
    'status.expired'  => 'Abgelaufen',
    'status.inactive' => 'Deaktiviert',
    'status.invalid'  => 'Ungültig',
    'status.loading'  => 'Lädt...',
    'status.not-set'  => 'Nicht gesetzt',
    'status.valid'    => 'Gültig',

];

==> bplan-base-globals-1.1.0-0b4347.zip: lang/de/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'de',
    'language' => 'Deutsch',
    'locale' => 'de_DE',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value €',
    'currency.format.negative' => '-:value €',
    'currency.iso4217.alpha'   => 'EUR',
    'currency.iso4217.numeric' => 978,
    'currency.name'            => 'Euro',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Eurocent',
    'currency.subunit.symbol'  => 'ct',
    'currency.symbol'          => '€',

    'date.format'       => 'd.m.Y',
    'datetime.format'   => 'd.m.Y, H:i',
    'datetime.format+'  => 'd.m.Y, H:i:s',
    'datetime.format-+' => 'd.m.Y, H:i \U\h\r',
    'datetime.format++' => 'd.m.Y, H:i:s \U\h\r',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i \U\h\r',
    'time.format++'     => 'H:i:s \U\h\r',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => '.',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------


    'action.activate'      => 'Aktivieren',
    'action.add'           => 'Hinzufügen',
    'action.cancel'        => 'Abbrechen',
    'action.cancel-upload' => 'Hochladen abbrechen',
    'action.change'        => 'Ändern',
    'action.close'         => 'Schließen',
    'action.confirm'       => 'Bestätigen',
    'action.deactivate'    => 'Deaktivieren',
    'action.delete'        => 'Löschen',
    'action.edit'          => 'Bearbeiten',
    'action.import'        => 'Importieren',
    'action.print'         => 'Drucken',
    'action.save'          => 'Speichern',
    'action.search'        => 'Suchen',
    'action.sync'          => 'Synchronisieren',
    'action.upload'        => 'Datei hochladen',
    'action.verify'        => 'Verifizieren',
    'action.view'          => 'Anzeigen',

    'languages' => [
        'bg' => 'Bulgarisch',
        'de' => 'Deutsch',
        'en' => 'Englisch',
        'es' => 'Spanisch',
        'fr' => 'Französisch',
        'hu' => 'Ungarisch',
        'it' => 'Italienisch',
        'lt' => 'Litauisch',
        'pl' => 'Polnisch',
        'ro' => 'Rumänisch',
        'ru' => 'Russisch',
        'tr' => 'Türkisch',
        'uk' => 'Ukrainisch',
    ],

    'option.yes' => 'Ja',
    'option.no'  => 'Nein',

    'required-hint'   => 'Markierte Felder (<span class="required-marker">:marker</span>) sind Pflichtfelder',
    'required-marker' => '*',

    'select-option.please-select' => ' -- Bitte wählen -- ',

    'status.active'   => 'Aktiv',
    'status.expired'  => 'Abgelaufen',
    'status.inactive' => 'Deaktiviert',
    'status.invalid'  => 'Ungültig',
    'status.loading'  => 'Lädt...',
    'status.not-set'  => 'Nicht gesetzt',
    'status.valid'    => 'Gültig',

];
